==> resume-0.2.30.crate: resume-0.2.30/lib.rs <==
#![doc(html_logo_url = "https://avatars.githubusercontent.com/u/54848194?v=4")]
#![feature(doc_auto_cfg)]

//! # BTW I USE ARCH
//!
//! Hello world!

// Globals are declared outside all other scopes.
#[cfg(feature = "arch")]
pub static LANGUAGE: &str = "Rust";
#[cfg(feature = "arch")]
pub const THRESHOLD: i32 = 10;

#[cfg(feature = "arch")]
pub type Tuple0_0 = ();
pub type Int8 = i8;

#[macro_export]
macro_rules! micro {
        () => {};
}

pub struct Unit;

pub fn array_length(array: &[u8]) -> usize {
    array.len()
}

#[cfg(any(feature = "arch", feature = "linux"))]
pub enum Devices {
    Pixelbook,
    Pixel5,
}

#[cfg(not(feature = "arch"))]
pub enum Topics {
    Rust,
    Go,
    WebAssembly,
    Clojure,
    TypeScript,
}

// #[cfg_attr(feature = "magic", twitter, github)]
pub mod social {
    pub const Twitter: &str = "btwiuse";
    pub const GitHub: &str = "btwiuse";
}

pub mod BTW {
    pub mod I {
        pub mod USE {
            pub mod ARCH {
            }
        }
    }
}

pub mod title;

#[cfg(all(feature = "arch", feature = "linux"))]
pub mod how_to_install_archlinux;

pub mod Español {}
pub mod 日本語 {}

#[cfg(feature = "arch")]
pub struct Arch;

#[cfg(feature = "arch")]
impl TagArch for Arch {}

#[cfg(feature = "arch")]
pub use BTW::I::USE::ARCH::*;

pub trait Empty {}

pub trait Any {}

impl Empty for () {}

impl<T: Empty> Any for T {}

pub trait GitHub {}

#[cfg(feature = "linux")]
pub trait TagLinux {}

#[cfg(feature = "arch")]
pub trait TagArch {}

pub trait Windows {}

pub trait Clash {}

pub trait MacOS {}

pub trait Rust {}

pub trait 中文 {}

==> resume-0.2.32.crate: resume-0.2.32/lib.rs <==
#![doc(html_logo_url = "https://avatars.githubusercontent.com/u/54848194?v=4")]
#![feature(doc_auto_cfg)]

//! # BTW I USE ARCH
//!
//! Hello world!

// Globals are declared outside all other scopes.
#[cfg(feature = "arch")]
pub static LANGUAGE: &str = "Rust";
#[cfg(feature = "arch")]
pub const THRESHOLD: i32 = 10;

#[cfg(feature = "arch")]
pub type Tuple0_0 = ();
pub type Int8 = i8;

#[macro_export]
macro_rules! micro {
        () => {};
}

pub struct Unit;

pub fn array_length(array: &[u8]) -> usize {
    array.len()
}

#[cfg(any(feature = "arch", feature = "linux"))]
pub enum Devices {
    Pixelbook,
    Pixel5,
}

#[cfg(not(feature = "arch"))]
pub enum Topics {
    Rust,
    Go,
    WebAssembly,
    Clojure,
    TypeScript,
}

// #[cfg_attr(feature = "magic", twitter, github)]
pub mod social {
    pub const Twitter: &str = "btwiuse";
    pub const GitHub: &str = "btwiuse";
}

pub mod BTW {
    pub mod I {
        pub mod USE {
            pub mod ARCH {
            }
        }
    }
}

pub mod title;

#[cfg(all(feature = "arch", feature = "linux"))]
pub mod how_to_install_archlinux;

pub mod Español {}
pub mod 日本語 {}

#[cfg(feature = "arch")]
pub struct Arch;

#[cfg(feature = "arch")]
impl TagArch for Arch {}

pub struct Linux;

impl TagLinux for Linux {}

pub struct ArchLinux;

impl TagArch for ArchLinux {}
impl TagLinux for ArchLinux {}

#[cfg(feature = "arch")]
pub use BTW::I::USE::ARCH;
//pub use BTW::I::USE::ARCH::*;

pub trait Empty {}

pub trait Any {}

impl Empty for () {}

impl<T: Empty> Any for T {}

pub trait GitHub {}

#[cfg(feature = "linux")]
pub trait TagLinux {}

#[cfg(feature = "arch")]
pub trait TagArch {}

pub trait Windows {}

pub trait Clash {}

pub trait MacOS {}

pub trait Rust {}

pub trait 中文 {}
